@@ -22,7 +22,7 @@
 
 G_BEGIN_DECLS
 
-void app_show_about(void);
+void app_show_about(GtkWidget *parent);
 
 G_END_DECLS
 
