@@ -25,6 +25,7 @@
 #include <rm/rm.h>
 
 #include <roger/contacts.h>
+#include <roger/contactsearch.h>
 #include <roger/main.h>
 #include <roger/uitools.h>
 #include <roger/phone.h>
@@ -147,28 +148,7 @@ static void contacts_update_details(RmContact *contact)
 				GtkWidget *phone_image;
 				RmPhoneNumber *phone_number = numbers->data;
 
-				switch (phone_number->type) {
-				case RM_PHONE_NUMBER_TYPE_HOME:
-					type = ui_label_new(_("Private"));
-					break;
-				case RM_PHONE_NUMBER_TYPE_WORK:
-					type = ui_label_new(_("Business"));
-					break;
-				case RM_PHONE_NUMBER_TYPE_MOBILE:
-					type = ui_label_new(_("Mobile"));
-					break;
-				case RM_PHONE_NUMBER_TYPE_FAX_HOME:
-					type = ui_label_new(_("Private Fax"));
-					break;
-				case RM_PHONE_NUMBER_TYPE_FAX_WORK:
-					type = ui_label_new(_("Business Fax"));
-					break;
-				case RM_PHONE_NUMBER_TYPE_PAGER:
-					type = ui_label_new(_("Pager"));
-					break;
-				default:
-					type = ui_label_new(_("Unknown"));
-				}
+				type = ui_label_new (phone_number_type_to_string (phone_number));
 
 				number = gtk_label_new(phone_number->number);
 				gtk_label_set_selectable(GTK_LABEL(number), TRUE);
@@ -719,7 +699,6 @@ void refresh_edit_dialog(RmContact *contact)
 
 		remove = gtk_button_new();
 		gtk_widget_set_tooltip_text(remove, _("Remove address"));
-		phone_image = gtk_image_new_from_icon_name("user-trash-symbolic", GTK_ICON_SIZE_BUTTON);
 		phone_image = gtk_image_new_from_icon_name(APP_ICON_TRASH, GTK_ICON_SIZE_BUTTON);
 		gtk_button_set_image(GTK_BUTTON(remove), phone_image);
 		g_signal_connect(remove, "clicked", G_CALLBACK(remove_address_clicked_cb), contact);
@@ -922,6 +901,7 @@ void contacts_book_clicked_cb(GtkWidget *widget, gpointer user_data)
 	}
 
 	gtk_widget_show_all(menu);
+  gtk_widget_set_sensitive (menu, TRUE);
 }
 
 void contact_editor(RmContact *contact)
