@@ -1,6 +1,6 @@
 /*
  * Roger Router
- * Copyright (c) 2012-2018 Jan-Michael Brummer
+ * Copyright (c) 2012-2020 Jan-Michael Brummer
  *
  * This file is part of Roger Router.
  *
@@ -28,6 +28,7 @@
 #include <gdk/gdk.h>
 #include <glib.h>
 #include <glib/gstdio.h>
+#include <handy.h>
 
 #include <rm/rm.h>
 
@@ -41,9 +42,11 @@
 #include "roger/answeringmachine.h"
 
 struct _RogerJournal {
-	GtkApplicationWindow parent_instance;
+	HdyWindow parent_instance;
 
+  GtkWidget *header_bars_stack;
   GtkWidget *headerbar;
+  GtkWidget *content_stack;
   GtkWidget *journal_listbox;
   GtkWidget *menu_button;
   GtkWidget *filter_combobox;
@@ -54,7 +57,7 @@ struct _RogerJournal {
   RmFilter *search_filter;
   GSList *list;
   GtkWidget *search_bar;
-  GtkWidget *search_button;
+  GtkWidget *search_entry;
 
   GtkWidget *col0;
   GtkWidget *col1;
@@ -71,11 +74,11 @@ struct _RogerJournal {
 
   gboolean hide_on_quit;
   gboolean hide_on_start;
+  gboolean mobile;
+  gboolean active;
 };
 
-G_DEFINE_TYPE(RogerJournal, roger_journal, GTK_TYPE_APPLICATION_WINDOW)
-
-//#define RESPONSIVE_DESIGN 1
+G_DEFINE_TYPE(RogerJournal, roger_journal, HDY_TYPE_WINDOW)
 
 static GdkPixbuf *icon_call_in = NULL;
 static GdkPixbuf *icon_call_missed = NULL;
@@ -86,10 +89,22 @@ static GdkPixbuf *icon_voice = NULL;
 static GdkPixbuf *icon_record = NULL;
 static GdkPixbuf *icon_blocked = NULL;
 
+static GSettings *journal_window_state = NULL;
+
+static void
+clear_listbox (GtkWidget *widget,
+               gpointer   data)
+{
+  gtk_widget_destroy (widget);
+}
+
 void
 journal_clear (RogerJournal *journal)
 {
-	gtk_list_store_clear (journal->list_store);
+  if (journal->mobile)
+    gtk_container_foreach (GTK_CONTAINER (journal->journal_listbox), clear_listbox, NULL);
+  else
+	  gtk_list_store_clear (journal->list_store);
 }
 
 static void
@@ -146,7 +161,6 @@ get_call_icon (gint type)
 	return NULL;
 }
 
-#ifdef RESPONSIVE_DESIGN
 static void
 box_header_func (GtkListBoxRow *row,
                  GtkListBoxRow *before,
@@ -166,7 +180,6 @@ box_header_func (GtkListBoxRow *row,
     gtk_list_box_row_set_header (row, current);
   }
 }
-#endif
 
 void
 journal_redraw (RogerJournal *self)
@@ -191,73 +204,78 @@ journal_redraw (RogerJournal *self)
 			continue;
 		}
 
-#ifndef RESPONSIVE_DESIGN
-		GtkTreeIter iter;
+    if (!self->mobile) {
+		  GtkTreeIter iter;
 
-		gtk_list_store_insert_with_values(self->list_store, &iter, -1,
-						  JOURNAL_COL_TYPE, get_call_icon(call->type),
-						  JOURNAL_COL_DATETIME, call->date_time,
-						  JOURNAL_COL_NAME, call->remote->name,
-						  JOURNAL_COL_COMPANY, call->remote->company,
-						  JOURNAL_COL_NUMBER, call->remote->number,
-						  JOURNAL_COL_CITY, call->remote->city,
-						  JOURNAL_COL_EXTENSION, call->local->name,
-						  JOURNAL_COL_LINE, call->local->number,
-						  JOURNAL_COL_DURATION, call->duration,
-						  JOURNAL_COL_CALL_PTR, call,
-						  -1);
-#else
-  GtkWidget *row = gtk_list_box_row_new ();
-  GtkWidget *grid = gtk_grid_new ();
-  GtkWidget *icon;
-  GtkWidget *name;
-  GtkWidget *date;
-  GtkWidget *phone;
-  GtkWidget *duration;
-  g_autofree gchar *tmp = NULL;
+		  gtk_list_store_insert_with_values(self->list_store, &iter, -1,
+						    JOURNAL_COL_TYPE, get_call_icon(call->type),
+						    JOURNAL_COL_DATETIME, call->date_time,
+						    JOURNAL_COL_NAME, call->remote->name,
+						    JOURNAL_COL_COMPANY, call->remote->company,
+						    JOURNAL_COL_NUMBER, call->remote->number,
+						    JOURNAL_COL_CITY, call->remote->city,
+						    JOURNAL_COL_EXTENSION, call->local->name,
+						    JOURNAL_COL_LINE, call->local->number,
+						    JOURNAL_COL_DURATION, call->duration,
+						    JOURNAL_COL_CALL_PTR, call,
+						    -1);
+    } else {
+      GtkWidget *row = gtk_list_box_row_new ();
+      GtkWidget *grid = gtk_grid_new ();
+      GtkWidget *icon;
+      GtkWidget *name;
+      GtkWidget *date;
+      GtkWidget *phone;
+      g_autofree gchar *tmp = NULL;
 
-  gtk_container_set_border_width (GTK_CONTAINER (grid), 6);
+      gtk_container_set_border_width (GTK_CONTAINER (grid), 6);
 
-  icon = gtk_image_new_from_pixbuf (get_call_icon(call->type));
-  gtk_grid_attach (GTK_GRID (grid), icon, 0, 0, 1, 3);
-  gtk_grid_set_row_spacing (GTK_GRID(grid), 6);
-  gtk_grid_set_column_spacing(GTK_GRID(grid), 12);
+      icon = gtk_image_new_from_pixbuf (get_call_icon(call->type));
+      gtk_grid_attach (GTK_GRID (grid), icon, 0, 0, 1, 2);
+      gtk_grid_set_row_spacing (GTK_GRID(grid), 6);
+      gtk_grid_set_column_spacing(GTK_GRID(grid), 12);
 
-  tmp = g_strdup (call->date_time);
-  date = gtk_label_new (tmp);
-  gtk_label_set_line_wrap (GTK_LABEL(date), TRUE);
-  gtk_label_set_xalign (GTK_LABEL(date), 0.0f);
-  gtk_widget_set_sensitive (date, FALSE);
-  gtk_grid_attach (GTK_GRID (grid), date, 1, 0, 1, 1);
+      if (!RM_EMPTY_STRING (call->remote->name)) {
+        name = gtk_label_new (call->remote->name);
+      } else {
+        name = gtk_label_new (_("Unknown"));
+        gtk_widget_set_sensitive (name, FALSE);
+      }
+      gtk_label_set_line_wrap (GTK_LABEL(name), TRUE);
+      gtk_widget_set_hexpand(name, TRUE);
+      gtk_label_set_ellipsize (GTK_LABEL (name), PANGO_ELLIPSIZE_END);
+      PangoAttrList *attrlist = pango_attr_list_new ();
+      PangoAttribute *attr = pango_attr_weight_new (PANGO_WEIGHT_SEMIBOLD);
+      pango_attr_list_insert (attrlist, attr);
+      gtk_label_set_attributes (GTK_LABEL (name), attrlist);
+      pango_attr_list_unref (attrlist);
 
-  name = gtk_label_new (call->remote->name);
-  gtk_label_set_line_wrap (GTK_LABEL(name), TRUE);
-  gtk_widget_set_hexpand(name, TRUE);
-  PangoAttrList *attrlist = pango_attr_list_new ();
-  PangoAttribute *attr = pango_attr_weight_new (PANGO_WEIGHT_SEMIBOLD);
-  pango_attr_list_insert (attrlist, attr);
-  gtk_label_set_attributes (GTK_LABEL (name), attrlist);
-  pango_attr_list_unref (attrlist);
+      gtk_label_set_xalign (GTK_LABEL(name), 0.0f);
+      gtk_grid_attach (GTK_GRID (grid), name, 1, 0, 2, 1);
 
-  gtk_label_set_xalign (GTK_LABEL(name), 0.0f);
-  gtk_grid_attach (GTK_GRID (grid), name, 1, 1, 1, 1);
+      phone = gtk_label_new (call->remote->number);
+      gtk_label_set_line_wrap (GTK_LABEL(phone), TRUE);
+      gtk_widget_set_sensitive (phone, FALSE);
+      gtk_label_set_xalign (GTK_LABEL(phone), 0.0f);
+      gtk_grid_attach (GTK_GRID (grid), phone, 1, 1, 1, 1);
 
-  phone = gtk_label_new (call->remote->number);
-  gtk_label_set_line_wrap (GTK_LABEL(phone), TRUE);
-  gtk_widget_set_sensitive (phone, FALSE);
-  gtk_label_set_xalign (GTK_LABEL(phone), 0.0f);
-  gtk_grid_attach (GTK_GRID (grid), phone, 1, 2, 1, 1);
+      tmp = g_strdup (call->date_time);
+      date = gtk_label_new (tmp);
+      gtk_label_set_line_wrap (GTK_LABEL(date), TRUE);
+      gtk_label_set_xalign (GTK_LABEL(date), 1.0f);
+      gtk_widget_set_sensitive (date, FALSE);
+      gtk_grid_attach (GTK_GRID (grid), date, 2, 1, 1, 1);
 
-  duration = gtk_label_new(call->duration);
-  gtk_label_set_xalign (GTK_LABEL(duration), 1.0f);
-  gtk_grid_attach (GTK_GRID (grid), duration, 2, 0, 1, 3);
+      /*duration = gtk_label_new(call->duration);
+      gtk_label_set_xalign (GTK_LABEL(duration), 1.0f);
+      gtk_grid_attach (GTK_GRID (grid), duration, 2, 0, 1, 3);*/
 
-  gtk_widget_show_all (grid);
+      gtk_widget_show_all (grid);
 
-  gtk_container_add (GTK_CONTAINER (row), grid);
-  gtk_widget_show_all (row);
-  gtk_list_box_insert (GTK_LIST_BOX(self->journal_listbox), row, -1);
-#endif
+      gtk_container_add (GTK_CONTAINER (row), grid);
+      gtk_widget_show_all (row);
+      gtk_list_box_insert (GTK_LIST_BOX(self->journal_listbox), row, -1);
+    }
 		if (call->duration && strchr(call->duration, 's') != NULL) {
 			/* Ignore voicebox duration */
 		} else {
@@ -272,9 +290,9 @@ journal_redraw (RogerJournal *self)
 
 	profile = rm_profile_get_active();
 
-  gtk_header_bar_set_title (GTK_HEADER_BAR (self->headerbar), profile ? profile->name : _("<No profile>"));
+  hdy_header_bar_set_title (HDY_HEADER_BAR (self->headerbar), profile ? profile->name : _("<No profile>"));
 	g_autofree gchar *markup = g_strdup_printf(_("%d calls, %d:%2.2dh"), count, duration / 60, duration % 60);
-  gtk_header_bar_set_subtitle (GTK_HEADER_BAR (self->headerbar), markup);
+  hdy_header_bar_set_subtitle (HDY_HEADER_BAR (self->headerbar), markup);
 
 	g_free(text);
 }
@@ -333,6 +351,28 @@ lookup_journal (gpointer user_data)
 void journal_filter_box_changed(GtkComboBox *box, gpointer user_data);
 static void journal_update_filter_box (RogerJournal *self);
 
+void
+journal_update_content (RogerJournal *self)
+{
+  RmProfile *profile = rm_profile_get_active ();
+
+  if (!profile) {
+    gtk_stack_set_visible_child_name (GTK_STACK (self->content_stack), "welcome");
+    gtk_stack_set_visible_child_name (GTK_STACK (self->header_bars_stack), "empty");
+    return;
+  }
+
+  gtk_stack_set_visible_child_name (GTK_STACK (self->header_bars_stack), "full");
+
+  if (self->mobile) {
+    gtk_stack_set_visible_child_name (GTK_STACK (self->content_stack), "mobile");
+    gtk_widget_set_visible (self->filter_combobox, FALSE);
+  } else {
+    gtk_stack_set_visible_child_name (GTK_STACK (self->content_stack), "treeview");
+    gtk_widget_set_visible (self->filter_combobox, TRUE);
+  }
+}
+
 static void
 on_journal_loaded(RmObject *obj,
                   GSList   *list,
@@ -346,6 +386,11 @@ on_journal_loaded(RmObject *obj,
 		return;
 	}
 
+  if (!self->active) {
+    self->active = TRUE;
+    journal_update_content (self);
+  }
+
 	if (!self->list && list) {
 		journal_update_filter_box (self);
 	}
@@ -611,12 +656,9 @@ row_activated_foreach (GtkTreeModel *model,
 
 		if (data && len) {
 			g_autofree gchar *path = g_build_filename(rm_get_user_cache_dir(), G_DIR_SEPARATOR_S, "fax.pdf", NULL);
-			g_autofree gchar *uri;
 
 			rm_file_save(path, data, len);
 
-			uri = g_strdup_printf("file:///%s", path);
-
 			app_pdf(data, len, NULL);
 		}
 		break;
@@ -953,20 +995,12 @@ on_key_press_event (GtkWidget *widget,
                     gpointer   user_data)
 {
   RogerJournal *self = ROGER_JOURNAL (widget);
-	GdkEventKey *key = (GdkEventKey*)event;
-	gint ret;
 
-	ret = gtk_search_bar_handle_event(GTK_SEARCH_BAR(self->search_bar), event);
+  if (g_strcmp0 (gtk_stack_get_visible_child_name (GTK_STACK (self->header_bars_stack)), "empty") == 0) {
+      return GDK_EVENT_PROPAGATE;
+  }
 
-	if (ret != GDK_EVENT_STOP) {
-		if (key->keyval == GDK_KEY_Escape) {
-			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(self->search_button), FALSE);
-		}
-	} else {
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(self->search_button), TRUE);
-	}
-
-	return ret;
+	return hdy_search_bar_handle_event(HDY_SEARCH_BAR(self->search_bar), event);
 }
 
 static const GActionEntry window_entries [] =
@@ -986,14 +1020,109 @@ static const GActionEntry window_entries [] =
 	{ "contacts-edit-address-work", contacts_add_detail_activated },*/
 };
 
+static void
+roger_journal_constructed (GObject *object)
+{
+  RogerJournal *journal = ROGER_JOURNAL (object);
+  g_autoptr (GVariant) default_size = NULL;
+  gboolean maximized;
+  gboolean fullscreen;
+  int default_width;
+  int default_height;
+
+  maximized = g_settings_get_boolean (journal_window_state, "maximized");
+  fullscreen = g_settings_get_boolean (journal_window_state, "fullscreen");
+  default_size = g_settings_get_value (journal_window_state,
+                                       "initial-size");
+
+  g_variant_get (default_size, "(ii)", &default_width, &default_height);
+
+  gtk_window_set_default_size (GTK_WINDOW (journal), default_width, default_height);
+
+  if (maximized)
+    gtk_window_maximize (GTK_WINDOW (journal));
+
+  if (fullscreen)
+    gtk_window_fullscreen (GTK_WINDOW (journal));
+
+  G_OBJECT_CLASS (roger_journal_parent_class)->constructed (object);
+
+  if (!journal->hide_on_start)
+		gtk_widget_show (GTK_WIDGET (journal));
+}
+
+static void
+roger_journal_dispose (GObject *self)
+{
+  RogerJournal *journal = ROGER_JOURNAL (self);
+  gboolean is_maximized;
+
+  if (gtk_widget_get_window (GTK_WIDGET (journal))) {
+    GVariant *initial_size;
+    int width;
+    int height;
+
+    gtk_window_get_size (GTK_WINDOW (journal), &width, &height);
+
+    initial_size = g_variant_new_parsed ("(%i, %i)", width, height);
+    is_maximized = gdk_window_get_state (gtk_widget_get_window (GTK_WIDGET (journal))) & GDK_WINDOW_STATE_MAXIMIZED;
+
+    if (!is_maximized)
+      g_settings_set_value (journal_window_state, "initial-size", initial_size);
+
+    g_settings_set_boolean (journal_window_state, "maximized", is_maximized);
+  }
+
+	if (journal->list) {
+		g_slist_free_full (g_steal_pointer (&journal->list), rm_call_entry_free);
+	}
+
+  G_OBJECT_CLASS (roger_journal_parent_class)->dispose (self);
+}
+
+static void
+roger_journal_size_allocate (GtkWidget     *self,
+                             GtkAllocation *allocation)
+{
+  RogerJournal *journal = ROGER_JOURNAL (self);
+  GtkAllocation alloc;
+  gboolean mobile;
+
+  GTK_WIDGET_CLASS (roger_journal_parent_class)->size_allocate (self, allocation);
+
+  gtk_widget_get_allocated_size (self, &alloc, NULL);
+  mobile = alloc.width < 500;
+
+  if (!journal->active) {
+    journal->mobile = mobile;
+    return;
+  }
+
+
+  if (journal->mobile != mobile) {
+    journal_clear (journal);
+    journal->mobile = mobile;
+    journal_update_content (journal);
+    journal_redraw (journal);
+  }
+}
+
 static void
 roger_journal_class_init (RogerJournalClass *klass)
 {
 	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
+  GObjectClass *object_class = G_OBJECT_CLASS (klass);
+
+  widget_class->size_allocate = roger_journal_size_allocate;
+  object_class->constructed = roger_journal_constructed;
+  object_class->dispose = roger_journal_dispose;
 
   gtk_widget_class_set_template_from_resource (widget_class, "/org/tabos/roger/ui/roger-journal.ui");
 
+ 	gtk_widget_class_bind_template_child (widget_class, RogerJournal, header_bars_stack);
  	gtk_widget_class_bind_template_child (widget_class, RogerJournal, headerbar);
+ 	gtk_widget_class_bind_template_child (widget_class, RogerJournal, content_stack);
+
  	gtk_widget_class_bind_template_child (widget_class, RogerJournal, journal_listbox);
  	gtk_widget_class_bind_template_child (widget_class, RogerJournal, menu_button);
  	gtk_widget_class_bind_template_child (widget_class, RogerJournal, filter_combobox);
@@ -1001,7 +1130,7 @@ roger_journal_class_init (RogerJournalClass *klass)
  	gtk_widget_class_bind_template_child (widget_class, RogerJournal, list_store);
  	gtk_widget_class_bind_template_child (widget_class, RogerJournal, spinner);
  	gtk_widget_class_bind_template_child (widget_class, RogerJournal, search_bar);
- 	gtk_widget_class_bind_template_child (widget_class, RogerJournal, search_button);
+ 	gtk_widget_class_bind_template_child (widget_class, RogerJournal, search_entry);
  	gtk_widget_class_bind_template_child (widget_class, RogerJournal, col0);
  	gtk_widget_class_bind_template_child (widget_class, RogerJournal, col1);
  	gtk_widget_class_bind_template_child (widget_class, RogerJournal, col2);
@@ -1012,6 +1141,7 @@ roger_journal_class_init (RogerJournalClass *klass)
  	gtk_widget_class_bind_template_child (widget_class, RogerJournal, col7);
  	gtk_widget_class_bind_template_child (widget_class, RogerJournal, col8);
  	gtk_widget_class_bind_template_child (widget_class, RogerJournal, col2_renderer);
+ 	gtk_widget_class_bind_template_child (widget_class, RogerJournal, content_stack);
 
   gtk_widget_class_bind_template_callback (widget_class, on_key_press_event);
   gtk_widget_class_bind_template_callback (widget_class, on_search_entry_changed);
@@ -1028,6 +1158,8 @@ roger_journal_init (RogerJournal *self)
   GtkTreeSortable *sortable;
   GSimpleActionGroup *simple_action_group;
 
+  journal_window_state = g_settings_new ("org.tabos.roger.window-state");
+
 	gtk_widget_init_template (GTK_WIDGET (self));
 
   /* Add actions */
@@ -1042,10 +1174,7 @@ roger_journal_init (RogerJournal *self)
 
 
   init_call_icons();
-
-	if (g_settings_get_boolean (app_settings, "maximized")) {
-		gtk_window_maximize (GTK_WINDOW (self));
-	}
+  self->list = NULL;
 
   g_type_ensure (G_TYPE_THEMED_ICON);
   GtkBuilder *builder = gtk_builder_new_from_resource ("/org/tabos/roger/ui/journal-popover.ui");
@@ -1053,9 +1182,8 @@ roger_journal_init (RogerJournal *self)
   gtk_menu_button_set_popover (GTK_MENU_BUTTON (self->menu_button), journal_popover);
   g_object_unref (builder);
 
-#ifdef RESPONSIVE_DESIGN
+  hdy_search_bar_connect_entry (HDY_SEARCH_BAR (self->search_bar), GTK_ENTRY (self->search_entry));
   gtk_list_box_set_header_func (GTK_LIST_BOX (self->journal_listbox), box_header_func, NULL, NULL);
-#endif
 
   journal_update_filter_box (self);
 
@@ -1090,18 +1218,13 @@ roger_journal_init (RogerJournal *self)
   g_settings_bind (app_settings, "col-8-width", self->col8, "fixed-width", G_SETTINGS_BIND_DEFAULT);
   g_settings_bind (app_settings, "col-8-visible", self->col8, "visible", G_SETTINGS_BIND_DEFAULT);
 
-  g_settings_bind (app_settings, "width", self, "default-width", G_SETTINGS_BIND_DEFAULT);
-  g_settings_bind (app_settings, "height", self, "default-height", G_SETTINGS_BIND_DEFAULT);
+  self->active = FALSE;
+  gtk_stack_set_visible_child_name (GTK_STACK (self->header_bars_stack), "empty");
+  gtk_stack_set_visible_child_name (GTK_STACK (self->content_stack), "loading");
 
-  g_object_bind_property (self->search_button, "active", self->search_bar, "search-mode-enabled", 0);
-
-  g_signal_connect (rm_object, "journal-loaded", G_CALLBACK (on_journal_loaded), self);
-	g_signal_connect (rm_object, "connection-changed", G_CALLBACK (on_connection_changed), self);
-	g_signal_connect (rm_object, "contacts-changed", G_CALLBACK (on_contacts_changed), self);
-
-  if (!self->hide_on_start) {
-		gtk_widget_show (GTK_WIDGET (self));
-	}
+  g_signal_connect_object (rm_object, "journal-loaded", G_CALLBACK (on_journal_loaded), self, 0);
+	g_signal_connect_object (rm_object, "connection-changed", G_CALLBACK (on_connection_changed), self, 0);
+	g_signal_connect_object (rm_object, "contacts-changed", G_CALLBACK (on_contacts_changed), self, 0);
 }
 
 RogerJournal *
